package com.ruoyi.execution.produce.dispersed.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.execution.produce.dispersed.enetity.BpmExecuteNode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.execution.produce.dispersed.mapper.BpmExecuteNodeMapper;
import com.ruoyi.execution.produce.dispersed.service.IBpmExecuteNodeService;

/**
 * 节点执行（记录）Service业务层处理
 * 
 * @author hzh
 * @date 2023-11-01
 */
@Service
public class BpmExecuteNodeServiceImpl implements IBpmExecuteNodeService 
{
    @Autowired
    private BpmExecuteNodeMapper bpmExecuteNodeMapper;

    /**
     * 查询节点执行（记录）
     * 
     * @param id 节点执行（记录）主键
     * @return 节点执行（记录）
     */
    @Override
    public BpmExecuteNode selectBpmExecuteNodeById(Long id)
    {
        return bpmExecuteNodeMapper.selectBpmExecuteNodeById(id);
    }

    /**
     * 查询节点执行（记录）列表
     * 
     * @param bpmExecuteNode 节点执行（记录）
     * @return 节点执行（记录）
     */
    @Override
    public List<BpmExecuteNode> selectBpmExecuteNodeList(BpmExecuteNode bpmExecuteNode)
    {
        return bpmExecuteNodeMapper.selectBpmExecuteNodeList(bpmExecuteNode);
    }

    /**
     * 新增节点执行（记录）
     * 
     * @param bpmExecuteNode 节点执行（记录）
     * @return 结果
     */
    @Override
    public int insertBpmExecuteNode(BpmExecuteNode bpmExecuteNode)
    {
        bpmExecuteNode.setCreateTime(DateUtils.getNowDate());
        return bpmExecuteNodeMapper.insertBpmExecuteNode(bpmExecuteNode);
    }

    /**
     * 修改节点执行（记录）
     * 
     * @param bpmExecuteNode 节点执行（记录）
     * @return 结果
     */
    @Override
    public int updateBpmExecuteNode(BpmExecuteNode bpmExecuteNode)
    {
        return bpmExecuteNodeMapper.updateBpmExecuteNode(bpmExecuteNode);
    }

    /**
     * 批量删除节点执行（记录）
     * 
     * @param ids 需要删除的节点执行（记录）主键
     * @return 结果
     */
    @Override
    public int deleteBpmExecuteNodeByIds(Long[] ids)
    {
        return bpmExecuteNodeMapper.deleteBpmExecuteNodeByIds(ids);
    }

    /**
     * 删除节点执行（记录）信息
     * 
     * @param id 节点执行（记录）主键
     * @return 结果
     */
    @Override
    public int deleteBpmExecuteNodeById(Long id)
    {
        return bpmExecuteNodeMapper.deleteBpmExecuteNodeById(id);
    }
}
